/*:
 * @plugindesc Plugin used to make the menus look a bit better for widescreen resolutions.
 * @author Fomar0153
 *
 * @help The default values are based on a new Window Width of 1104.
 *
 * @param Menu Left
 * @desc Have the command for the main menu be on the left.
 * @type boolean
 * @default true
 *
 * @param Command Widths
 * @desc The default is calculated by 240 + (1104 - 816) / 4
 * @type number
 * @default 312
 *
 * @param Simple Status Option
 * @desc Choose what option to use for the simple status
 * @type select
 * @option Longer HP/MP bars
 * @value 0
 * @option Display EXP
 * @value 1
 * @default 0
 *
 * @param Selectable Col Max
 * @desc For skills and items
 * @type number
 * @default 3
 *
 * @param Equipment Col Max
 * @desc How many columns for selectable equipment
 * @type number
 * @default 2
 *
 * @param Equip Extend Status
 * @desc Have the status window in the equipment menu display additional stats.
 * @type boolean
 * @default true
 *
 * @param Extra Display Parameters
 *
 * @param Display Name 1
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Accuracy
 *
 * @param Display Code 1
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.hit;
 *
 * @param Display Name 2
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Evasion
 *
 * @param Display Code 2
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.eva;
 *
 * @param Display Name 3
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Crit %
 *
 * @param Display Code 3
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.cri;
 *
 * @param Display Name 4
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Crit Eva
 *
 * @param Display Code 4
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.cev;
 *
 * @param Display Name 5
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Magic Eva
 *
 * @param Display Code 5
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.mev;
 *
 * @param Display Name 6
 * @text Display Name
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default Magic Ref
 *
 * @param Display Code 6
 * @text Display Code
 * @desc Display an extra parameter on the status screen (and optionally equip screen).
 * @parent Extra Display Parameters
 * @type text
 * @default this._actor.mrf;
 *
 */


var Fomar = Fomar || {};
Fomar.Widescreen = {};
Fomar.Widescreen.parameters = PluginManager.parameters('Fomar0153_Widescreen_Menu');

Fomar.Widescreen.menuLeft = JSON.parse(Fomar.Widescreen.parameters['Menu Left']);
Fomar.Widescreen.commandWidths = Number(Fomar.Widescreen.parameters['Command Widths']);
Fomar.Widescreen.simpleOption = Number(Fomar.Widescreen.parameters['Simple Status Option']);
Fomar.Widescreen.maxCols = Number(Fomar.Widescreen.parameters['Selectable Col Max']);
Fomar.Widescreen.maxColsEquip = Number(Fomar.Widescreen.parameters['Equipment Col Max']);
Fomar.Widescreen.equipdStatus = JSON.parse(Fomar.Widescreen.parameters['Equip Extend Status']);
Fomar.Widescreen.extraParams = [];
Fomar.Widescreen.extraParams[0] = [Fomar.Widescreen.parameters['Display Name 1'], Fomar.Widescreen.parameters['Display Code 1']];
Fomar.Widescreen.extraParams[1] = [Fomar.Widescreen.parameters['Display Name 2'], Fomar.Widescreen.parameters['Display Code 2']];
Fomar.Widescreen.extraParams[2] = [Fomar.Widescreen.parameters['Display Name 3'], Fomar.Widescreen.parameters['Display Code 3']];
Fomar.Widescreen.extraParams[3] = [Fomar.Widescreen.parameters['Display Name 4'], Fomar.Widescreen.parameters['Display Code 4']];
Fomar.Widescreen.extraParams[4] = [Fomar.Widescreen.parameters['Display Name 5'], Fomar.Widescreen.parameters['Display Code 5']];
Fomar.Widescreen.extraParams[5] = [Fomar.Widescreen.parameters['Display Name 6'], Fomar.Widescreen.parameters['Display Code 6']];

Window_MenuCommand.prototype.windowWidth = function() {
  return Fomar.Widescreen.commandWidths;
};

Window_SkillType.prototype.windowWidth = function() {
  return Fomar.Widescreen.commandWidths;
};

Window_Gold.prototype.windowWidth = function() {
  return Fomar.Widescreen.commandWidths;
};

Window_MenuStatus.prototype.windowWidth = function() {
  return Graphics.boxWidth - Fomar.Widescreen.commandWidths;
};

Window_Base.prototype.drawActorSimpleStatus = function(actor, x, y, width) {
  var lineHeight = this.lineHeight();
  var x2 = x + 180;
  var width2 = width - 180 - this.textPadding();
  switch (Fomar.Widescreen.simpleOption) {
    case 0:
      break;
    case 1:
      this.drawExpInfo(actor, x + 404, y)
    default:
      width2 = Math.min(200, width2);
  }
  this.drawActorName(actor, x, y);
  this.drawActorLevel(actor, x, y + lineHeight * 1);
  this.drawActorIcons(actor, x, y + lineHeight * 2);
  this.drawActorClass(actor, x2, y);
  this.drawActorHp(actor, x2, y + lineHeight * 1, width2);
  this.drawActorMp(actor, x2, y + lineHeight * 2, width2);
};

Window_Base.prototype.drawExpInfo = function(actor, x, y) {
  var width = this.width - x - this.standardPadding() * 2;
  console.log(width);
  var lineHeight = this.lineHeight();
  var expNext = TextManager.expNext.format(TextManager.level);
  var value1 = actor.currentExp();
  var value2 = actor.nextRequiredExp();
  if (actor.isMaxLevel()) {
    value1 = '-------';
    value2 = '-------';
  }
  this.changeTextColor(this.systemColor());
  this.drawText(expNext, x, y + lineHeight * 1, width);
  this.resetTextColor();
  this.drawText(value2, x, y + lineHeight * 2, width, 'right');
};

Window_Status.prototype.drawBlock1 = function(y) {
  var width = this.contentsWidth();
  var gap = 0;
  if (this._actor.nickname() == "") {
    gap = (width - 270 * 2) / 2;
  } else {
    gap = (width - 270 * 2 - 270) / 2;
  }
  this.drawActorName(this._actor, gap, y);
  this.drawActorClass(this._actor, gap + 270, y);
  this.drawActorNickname(this._actor, gap + 270 * 2, y);
};

Window_Status.prototype.drawActorName = function(actor, x, y, width) {
  width = width || 270;
  this.changeTextColor(this.hpColor(actor));
  this.drawText(actor.name(), x, y, width, 'center');
};

Window_Status.prototype.drawActorClass = function(actor, x, y, width) {
  width = width || 270;
  this.resetTextColor();
  this.drawText(actor.currentClass().name, x, y, width, 'center');
};

Window_Status.prototype.drawActorNickname = function(actor, x, y, width) {
  width = width || 270;
  this.resetTextColor();
  this.drawText(actor.nickname(), x, y, width, 'center');
};

Window_Status.prototype.drawBlock2 = function(y) {
  var width = this.contentsWidth();
  var gap = (width - 192 - 252 - 270) / 2
  this.drawActorFace(this._actor, gap, y);
  this.drawBasicInfo(gap + 192, y);
  this.drawExpInfo(gap + 192 + 252, y);
};

Window_Status.prototype.drawBlock3 = function(y) {
  var width = this.contentsWidth();
  var gap = (width - 220 * 2 - 288) / 4
  this.drawParameters(gap, y);
  this.drawExtraParameters(gap * 2 + 220, y);
  this.drawEquipments(gap * 3 + 220 * 2, y);
};

Window_Status.prototype.drawExtraParameters = function(x, y) {
  var lineHeight = this.lineHeight();
  for (var i = 0; i < 6; i++) {
    var y2 = y + lineHeight * i;
    this.changeTextColor(this.systemColor());
    this.drawText(Fomar.Widescreen.extraParams[i][0], x, y2, 160);
    this.resetTextColor();
    this.drawText(String(100 * eval(Fomar.Widescreen.extraParams[i][1])) + "%", x + 160, y2, 60, 'right');
  }
};

Window_Status.prototype.drawEquipments = function(x, y) {
  var equips = this._actor.equips();
  var count = Math.min(equips.length, this.maxEquipmentLines());
  for (var i = 0; i < count; i++) {
    this.changeTextColor(this.systemColor());
    this.drawText(this.slotName(i), x, y + this.lineHeight() * i, 138, this.lineHeight());
    this.resetTextColor();
    this.drawItemName(equips[i], x + 144, y + this.lineHeight() * i);
  }
};

Window_Status.prototype.slotName = function(index) {
  var slots = this._actor.equipSlots();
  return this._actor ? $dataSystem.equipTypes[slots[index]] : '';
};

Fomar.Widescreen.Scene_Menu_createStatusWindow = Scene_Menu.prototype.createStatusWindow;
Scene_Menu.prototype.createStatusWindow = function() {
  Fomar.Widescreen.Scene_Menu_createStatusWindow.call(this);
  if (Fomar.Widescreen.menuLeft == false) {
    this._statusWindow.x = 0;
    this._commandWindow.x = this._statusWindow.width;
    this._goldWindow.x = this._statusWindow.width;
  }
};

Window_SkillList.prototype.maxCols = function() {
  return Fomar.Widescreen.maxCols;
};

Window_ItemList.prototype.maxCols = function() {
  return Fomar.Widescreen.maxCols;
};

Window_EquipStatus.prototype.windowWidth = function() {
  return Math.max(312, Fomar.Widescreen.commandWidths);
};

Window_EquipStatus.prototype.windowHeight = function() {
  if (Fomar.Widescreen.equipdStatus) {
    return Graphics.boxHeight - this.fittingHeight(2);
  } else {
    return this.fittingHeight(this.numVisibleRows());
  }
};

Fomar.Widescreen.Window_EquipStatus_refresh = Window_EquipStatus.prototype.refresh;
Window_EquipStatus.prototype.refresh = function() {
  Fomar.Widescreen.Window_EquipStatus_refresh.call(this);
  if (Fomar.Widescreen.equipdStatus == false) {
    return;
  }
  if (this._actor) {
    for (var i = 0; i < 6; i++) {
      this.drawExtraItem(0, this.lineHeight() * (7 + i), i);
    }
  }
};

Window_EquipStatus.prototype.drawItem = function(x, y, paramId) {
  var gap = Math.max(0, Math.min(20, (Fomar.Widescreen.commandWidths - 312) / 3));
  this.drawParamName(x + this.textPadding(), y, paramId);
  if (this._actor) {
    this.drawCurrentParam(x + 140, y, paramId);
  }
  this.drawRightArrow(x + 188 + gap, y);
  if (this._tempActor) {
    this.drawNewParam(x + 222 + gap * 2, y, paramId);
  }
};

Window_EquipStatus.prototype.drawCurrentParam = function(x, y, paramId) {
  var gap = Math.max(0, Math.min(20, (Fomar.Widescreen.commandWidths - 312) / 3));
  this.resetTextColor();
  this.drawText(this._actor.param(paramId), x, y, 48 + gap, 'right');
};

Window_EquipStatus.prototype.drawNewParam = function(x, y, paramId) {
  var gap = Math.max(0, Math.min(20, (Fomar.Widescreen.commandWidths - 312) / 3));
  var newValue = this._tempActor.param(paramId);
  var diffvalue = newValue - this._actor.param(paramId);
  this.changeTextColor(this.paramchangeTextColor(diffvalue));
  this.drawText(newValue, x, y, 48 + gap, 'right');
};

Window_EquipStatus.prototype.drawExtraItem = function(x, y, i) {
  var gap = Math.max(0, Math.min(20, (Fomar.Widescreen.commandWidths - 312) / 3));
  this.changeTextColor(this.systemColor());
  this.drawText(Fomar.Widescreen.extraParams[i][0], x, y, 140);
  if (this._actor) {
    this.resetTextColor();
    this.drawText(String(100 * eval(Fomar.Widescreen.extraParams[i][1])) + "%", x + 140, y, 48 + gap, 'right');
  }
  this.drawRightArrow(x + 188 + gap, y);
  if (this._tempActor) {
    this.resetTextColor();
    this.drawText(String(100 * eval(Fomar.Widescreen.extraParams[i][1].replace("_actor", "_tempActor"))) + "%", x + 222 + gap * 2, y, 48 + gap, 'right');
  }
};

Window_EquipItem.prototype.maxCols = function() {
  return Fomar.Widescreen.maxColsEquip;
};

Scene_Equip.prototype.createSlotWindow = function() {
  var wx = this._statusWindow.width;
  var wy = this._commandWindow.y + this._commandWindow.height;
  var ww = Graphics.boxWidth - this._statusWindow.width;
  var wh;
  if (Fomar.Widescreen.equipdStatus) {
    wh = this._statusWindow.fittingHeight(5);
  } else {
    wh = this._statusWindow.height - this._commandWindow.height;
  }
  this._slotWindow = new Window_EquipSlot(wx, wy, ww, wh);
  this._slotWindow.setHelpWindow(this._helpWindow);
  this._slotWindow.setStatusWindow(this._statusWindow);
  this._slotWindow.setHandler('ok', this.onSlotOk.bind(this));
  this._slotWindow.setHandler('cancel', this.onSlotCancel.bind(this));
  this.addWindow(this._slotWindow);
};

Scene_Equip.prototype.createItemWindow = function() {
  var wx;
  var wy;
  var ww;
  if (Fomar.Widescreen.equipdStatus) {
    wx = this._statusWindow.width;
    wy = this._slotWindow.y + this._slotWindow.height;
    ww = Graphics.boxWidth - wx;
  } else {
    wx = 0;
    wy = this._statusWindow.y + this._statusWindow.height;
    ww = Graphics.boxWidth;
  }
  var wh = Graphics.boxHeight - wy;
  this._itemWindow = new Window_EquipItem(wx, wy, ww, wh);
  this._itemWindow.setHelpWindow(this._helpWindow);
  this._itemWindow.setStatusWindow(this._statusWindow);
  this._itemWindow.setHandler('ok', this.onItemOk.bind(this));
  this._itemWindow.setHandler('cancel', this.onItemCancel.bind(this));
  this._slotWindow.setItemWindow(this._itemWindow);
  this.addWindow(this._itemWindow);
};
